@@ -159,7 +159,7 @@ class Sentinel1Etad:
         }
         dd = {}
         for tag, xp in xp_list.items():
-            dd[tag] = self._xpath_to_list(self._annot, xp, dtype=np.float)
+            dd[tag] = self._xpath_to_list(self._annot, xp, dtype=float)
         dd['unit'] = 'm'
         return dd
 
@@ -172,7 +172,7 @@ class Sentinel1Etad:
         }
         dd = {}
         for tag, xp in xp_list.items():
-            dd[tag] = self._xpath_to_list(self._annot, xp, dtype=np.float)
+            dd[tag] = self._xpath_to_list(self._annot, xp, dtype=float)
         dd['unit'] = 's'
         return dd
 
@@ -196,6 +196,19 @@ class Sentinel1Etad:
         """The maximum range time of all bursts in the product."""
         return self.ds.rangeTimeMax
 
+    @property
+    def vg(self):
+        """Mean ground velocity [m/s]."""
+        try:
+            xp = (
+                'productInformation/gridGroundSampling/'
+                'averageZeroDopplerVelocity'
+            )
+            vg = float(self._annot.find(xp).taxt)
+        except (AttributeError, ValueError):
+            vg = self.grid_spacing['y'] / self.grid_sampling['y']
+        return vg
+
     def processing_setting(self):
         """Return the corrections performed.
 
@@ -490,7 +503,7 @@ class Sentinel1Etad:
         return list(itertools.chain(*lists_of_burst_indexes))
 
     def _swath_merger(self, burst_var, selection=None, set_auto_mask=False,
-                      meter=False):
+                      meter=False, fill_value=0.):
         if selection is None:
             df = self.burst_catalogue
         elif not isinstance(selection, pd.DataFrame):
@@ -519,12 +532,14 @@ class Sentinel1Etad:
 
         num_samples = np.round(
             (rg_last_time - rg_first_time) / dx
-        ).astype(np.int) + 1
+        ).astype(int) + 1
         num_lines = np.round(
             (az_last_time - az_first_time).total_seconds() / dy
-        ).astype(np.int) + 1
+        ).astype(int) + 1
 
-        img = np.zeros((num_lines, num_samples))
+        img = np.full((num_lines, num_samples), fill_value=fill_value)
+        # TODO: add some control option
+        img = np.ma.array(img, mask=True, fill_value=fill_value)
 
         for swath in self.iter_swaths(df):
             # NOTE: use the private "Sentinel1EtadSwath._burst_merger" method
@@ -533,8 +548,8 @@ class Sentinel1Etad:
                                       set_auto_mask=set_auto_mask, meter=meter)
             yoffset = dd_['first_azimuth_time'] - az_first_time_rel
             xoffset = dd_['first_slant_range_time'] - rg_first_time
-            line_ofs = np.round(yoffset / dy).astype(np.int)
-            sample_ofs = np.round(xoffset / dx).astype(np.int)
+            line_ofs = np.round(yoffset / dy).astype(int)
+            sample_ofs = np.round(xoffset / dx).astype(int)
 
             slice_y = slice(line_ofs, line_ofs + dd_[burst_var].shape[0])
             slice_x = slice(sample_ofs, sample_ofs + dd_[burst_var].shape[1])
@@ -581,13 +596,14 @@ class Sentinel1Etad:
 
         dd['lats'] = self._swath_merger('lats', selection=filled_selection,
                                         set_auto_mask=set_auto_mask,
-                                        meter=False)
+                                        meter=False, fill_value=np.nan)['lats']
         dd['lons'] = self._swath_merger('lons', selection=filled_selection,
                                         set_auto_mask=set_auto_mask,
-                                        meter=False)
+                                        meter=False, fill_value=np.nan)['lons']
         dd['height'] = self._swath_merger('height', selection=filled_selection,
                                           set_auto_mask=set_auto_mask,
-                                          meter=False)
+                                          meter=False,
+                                          fill_value=np.nan)['height']
         return dd
 
     def merge_correction(self, name: CorrectionType = ECorrectionType.SUM,
@@ -803,7 +819,7 @@ class Sentinel1EtadSwath:
 
     def _burst_merger(self, burst_var, selection=None,
                       az_time_min=None, az_time_max=None,
-                      set_auto_mask=False, meter=False):
+                      set_auto_mask=False, meter=False, fill_value=0.):
         """Low level method to de-burst a NetCDF variable.
 
         The de-burst strategy is simple as the latest line is on top of the
@@ -854,13 +870,25 @@ class Sentinel1EtadSwath:
         else:
             t1 = az_time_max
 
-        # azimuth grid sampling
+        tau0 = min(
+            burst.sampling_start['x']
+            for burst in self.iter_bursts(burst_index_list)
+        )
+
+        # grid sampling
         dt = first_burst.sampling['y']
+        dtau = first_burst.sampling['x']
 
-        num_lines = np.round((t1 - t0) / dt).astype(np.int) + 1
-        num_samples = first_burst.samples
+        num_lines = np.round((t1 - t0) / dt).astype(int) + 1
+        num_samples = max(
+            burst.samples for burst in self.iter_bursts(burst_index_list)
+        )
 
-        debursted_var = np.zeros((num_lines, num_samples))
+        debursted_var = np.full((num_lines, num_samples),
+                                fill_value=fill_value)
+        # TODO: add some control option
+        debursted_var = np.ma.array(debursted_var,
+                                    mask=True, fill_value=fill_value)
 
         for burst_ in self.iter_bursts(burst_index_list):
             assert(dt == burst_.sampling['y']), \
@@ -871,7 +899,8 @@ class Sentinel1EtadSwath:
 
             # get the timing of the burst and convert into line index
             az_time_, rg_time_ = burst_.get_burst_grid()
-            line_index_ = np.round((az_time_ - t0) / dt).astype(np.int)
+            line_index_ = np.round((az_time_ - t0) / dt).astype(int)
+            p0 = np.round((rg_time_[0] - tau0) / dtau).astype(int)
 
             # NOTE: use the private "Sentinel1EtadBurst._get_etad_param" method
             # to be able to work only on the specified NetCDF variable
@@ -879,7 +908,8 @@ class Sentinel1EtadSwath:
                                           set_auto_mask=set_auto_mask,
                                           meter=meter)
 
-            debursted_var[line_index_, :] = var_
+            _, burst_samples = var_.shape
+            debursted_var[line_index_, p0:p0+burst_samples] = var_
 
         return {
             burst_var: debursted_var,
@@ -900,12 +930,13 @@ class Sentinel1EtadSwath:
             dd['first_slant_range_time'] = dd_['first_slant_range_time']
 
         dd['unit'] = 'm' if meter else 's'
-        dd['lats'] = self._burst_merger('lats', meter=False,
-                                        set_auto_mask=set_auto_mask)
-        dd['lons'] = self._burst_merger('lons', meter=False,
-                                        set_auto_mask=set_auto_mask)
-        dd['height'] = self._burst_merger('height', meter=False,
-                                          set_auto_mask=set_auto_mask)
+        dd['lats'] = self._burst_merger('lats', set_auto_mask=set_auto_mask,
+                                        meter=False)['lats']
+        dd['lons'] = self._burst_merger('lons', set_auto_mask=set_auto_mask,
+                                        meter=False)['lons']
+        dd['height'] = self._burst_merger('height',
+                                          set_auto_mask=set_auto_mask,
+                                          meter=False)['height']
         return dd
 
     def merge_correction(self, name: CorrectionType = ECorrectionType.SUM,
@@ -1103,6 +1134,70 @@ class Sentinel1EtadBurst:
         """The number of samples in the burst."""
         return self._grp.dimensions['rangeExtent'].size
 
+    @property
+    def vg(self) -> float:
+        """Average zero-Doppler ground velocity [m/s]."""
+        return self._grp.averageZeroDopplerVelocity
+
+    @property
+    def reference_polarization(self) -> str:
+        """Reverence polarization (string)."""
+        return self._grp.referencePolarization
+
+    def get_polarimetric_channel_offset(self, channel: str) -> dict:
+        """Polarimetric channel delay.
+
+        Return the electronic delay of the specified polarimetric channel
+        w.r.t. the reference one (see
+        :data:`Sentinel1EtadBurst.reference_polarization`).
+
+        channel : str
+            the string ID of the requested polarimetric channel:
+            * 'VV' or 'VH' for DV products
+            * 'HH' or 'HV' for DH products
+        """
+        if channel not in {'HH', 'HV', 'VV', 'VH'}:
+            raise ValueError(f'invalid channel ID: {channel!r}')
+
+        if channel[0] != self._grp.referencePolarization[0]:
+            raise ValueError(
+                f'polarimetric channel not available: {channel!r}')
+
+        data = dict(units='s')
+
+        if channel == 'HH':
+            data['x'] = self._grp.rangeOffsetHH,
+            data['y'] = self._grp.rangeOffsetHH,
+        elif channel == 'HV':
+            data['x'] = self._grp.rangeOffsetHV,
+            data['y'] = self._grp.rangeOffsetHV,
+        elif channel == 'VH':
+            data['x'] = self._grp.rangeOffsetVH,
+            data['y'] = self._grp.rangeOffsetVH,
+        elif channel == 'VV':
+            data['x'] = self._grp.rangeOffsetVV,
+            data['y'] = self._grp.rangeOffsetVV,
+
+        return data
+
+    def get_timing_calibration_constants(self) -> dict:
+        try:
+            return dict(
+                x=self._grp.instrumentTimingCalibrationRange,
+                y=self._grp.instrumentTimingCalibrationAzimuth,
+                units='s',
+            )
+        except AttributeError:
+            # @COMPATIBILITY: with SETAP , v1.6
+            warnings.warn(
+                'instrument timing calibration constants are not available '
+                'in the NetCDF data component this product. '
+                'Calibration constants have been added to the NetCDF '
+                'component in SETAP v1.6 (ETAD-DLR-PS-0014 - '
+                '"ETAD Product Format Specification" Issue 1.5).'
+            )
+            return dict(x=0, y=0, units='s')
+
     def _get_etad_param(self, name, set_auto_mask=False, transpose=False,
                         meter=False):
         assert name in self._grp.variables, f'Parameter {name!r} is not allowed'
